@@ -28,6 +28,8 @@
 #include "randrdisplay.h"
 #include "randrscreen.h"
 
+#include <kglobalsettings.h>
+
 RandRConfig::RandRConfig(QWidget *parent, RandRDisplay *display)
 	: QWidget(parent), Ui::RandRConfigBase()
 {
@@ -44,6 +46,10 @@ RandRConfig::RandRConfig(QWidget *parent, RandRDisplay *display)
 
 	setupUi(this);
 
+	connect( identifyOutputsButton, SIGNAL( clicked()), SLOT( identifyOutputs()));
+	connect( &identifyTimer, SIGNAL( timeout()), SLOT( clearIndicators()));
+	identifyTimer.setSingleShot( true );
+
 	// create the container for the settings widget
 	QHBoxLayout *layout = new QHBoxLayout(outputList);
 	layout->setSpacing(0);
@@ -56,12 +62,15 @@ RandRConfig::RandRConfig(QWidget *parent, RandRDisplay *display)
 	// create the scene
 	m_scene = new QGraphicsScene(m_display->currentScreen()->rect());	
 	screenView->setScene(m_scene);
+	screenView->installEventFilter(this);
 
 	m_layoutManager = new LayoutManager(m_display->currentScreen(), m_scene);
 }
 
 RandRConfig::~RandRConfig()
 {
+	clearIndicators();
+	delete m_scene;
 }
 
 void RandRConfig::load(void)
@@ -92,6 +101,7 @@ void RandRConfig::load(void)
 	foreach(RandROutput *output, outputs)
 	{
 		o = new OutputGraphicsItem(output);
+		o->setParent(m_scene);
 		m_scene->addItem(o);
 		
 		connect(o,    SIGNAL(itemChanged(OutputGraphicsItem*)), 
@@ -99,12 +109,13 @@ void RandRConfig::load(void)
 
 		OutputConfig *config = new OutputConfig(0, output, o);
 		
-		QString description = output->name() + 
-		                     (output->isConnected() ? " (Connected)" : "");
+		QString description = output->isConnected()
+			? i18n("%1 (Connected)", output->name())
+			: output->name();
 		w = m_container->insertWidget(config, description);
 		if(output->isConnected()) {
 			w->setExpanded(true);
-			kDebug() << "Output rect: " << output->rect();
+			kDebug() << "Output rect:" << output->rect();
 		}
 		m_outputList.append(w);
 		
@@ -129,7 +140,7 @@ void RandRConfig::defaults()
 
 void RandRConfig::apply()
 {
-	kDebug() << "Applying settings... ";
+	kDebug() << "Applying settings...";
 	foreach(CollapsibleWidget *w, m_outputList) {
 		OutputConfig *config = static_cast<OutputConfig *>(w->innerWidget());
 		RandROutput *output = config->output();
@@ -138,22 +149,24 @@ void RandRConfig::apply()
 			continue;
 		
 		QSize res = config->resolution();
-		QRect configuredRect(config->position(), res);
 		
 		if(!res.isNull()) {
-			if(output->rect() == configuredRect) {
-				kDebug() << "Ignoring identical config for " << output->name();
+			if(!config->hasPendingChanges()) {
+				kDebug() << "Ignoring identical config for" << output->name();
 				continue;
 			}
+			QRect configuredRect(config->position(), res);
+			
+			kDebug() << "Output config for" << output->name() << ":\n"
+			            "  rect =" << configuredRect
+			         << ", rot =" << config->rotation()
+			         << ", rate =" << config->refreshRate();
 			
-			kDebug() << "Output config: rect =" << configuredRect << ", rot = "
-			         << config->rotation() << ", rate =" << config->refreshRate();
-				    
 			output->proposeRect(configuredRect);
 			output->proposeRotation(config->rotation());
 			output->proposeRefreshRate(config->refreshRate());
 		} else { // user wants to disable this output
-			kDebug() << "Disabling " << output->name();
+			kDebug() << "Disabling" << output->name();
 			output->slotDisable();
 		}
 	}
@@ -175,16 +188,20 @@ void RandRConfig::update()
 	emit changed(false);
 }
 
-void RandRConfig::resizeEvent(QResizeEvent *event)
+bool RandRConfig::eventFilter(QObject *obj, QEvent *event)
 {
-    Q_UNUSED(event);
-	slotUpdateView();
+	if ( obj == screenView && event->type() == QEvent::Resize ) {
+		slotUpdateView();
+		return false;
+	} else {
+		return QWidget::eventFilter(obj, event);
+	}
 }
 
 void RandRConfig::slotAdjustOutput(OutputGraphicsItem *o)
 {
     Q_UNUSED(o);
-	kDebug() << "Output graphics item changed: ";
+	kDebug() << "Output graphics item changed:";
 	
 	// TODO: Implement
 }
@@ -219,5 +236,48 @@ void RandRConfig::slotUpdateView()
 	screenView->setSceneRect(r);
 }
 
+uint qHash( const QPoint& p )
+{
+	return p.x() * 10000 + p.y();
+}
+
+void RandRConfig::identifyOutputs()
+{
+	identifyTimer.stop();
+	clearIndicators();
+	QHash< QPoint, QStringList > ids; // outputs at centers of screens (can be more in case of clone mode)
+	OutputMap outputs = m_display->currentScreen()->outputs();
+	foreach(RandROutput *output, outputs)
+	{
+		if( !output->isConnected())
+			continue;
+		ids[ output->rect().center() ].append( output->name());
+	}
+	for( QHash< QPoint, QStringList >::ConstIterator it = ids.constBegin();
+	     it != ids.constEnd();
+	     ++it )
+	{
+		QLabel *si = new QLabel(it->join("\n"), NULL, Qt::X11BypassWindowManagerHint);
+		QFont fnt = KGlobalSettings::generalFont();
+		fnt.setPixelSize(100);
+		si->setFont(fnt);
+		si->setFrameStyle(QFrame::Panel);
+		si->setFrameShadow(QFrame::Plain);
+		si->setAlignment(Qt::AlignCenter);
+		QRect targetGeometry(QPoint(0,0), si->sizeHint());
+	        targetGeometry.moveCenter(it.key());
+		si->setGeometry(targetGeometry);
+		si->show();
+	        m_indicators.append( si );
+	}
+	identifyTimer.start( 1500 );
+}
+
+void RandRConfig::clearIndicators()
+{
+	qDeleteAll( m_indicators );
+	m_indicators.clear();
+}
+
 #include "randrconfig.moc"
 
