@@ -306,6 +306,11 @@ class Client
         const QPixmap *bottomDecoPixmap() const { return &decorationPixmapBottom; } 
         const QPixmap *rightDecoPixmap() const { return &decorationPixmapRight; } 
 
+        int paddingLeft() const { return padding_left; }
+        int paddingRight() const { return padding_right; }
+        int paddingTop() const { return padding_top; }
+        int paddingBottom() const { return padding_bottom; }
+
         bool decorationPixmapRequiresRepaint();
         void ensureDecorationPixmapsPainted();
 
@@ -320,6 +325,7 @@ class Client
             WindowRelative      // Relative to the top left corner of the window
         };
         void layoutDecorationRects(QRect &left, QRect &top, QRect &right, QRect &bottom, CoordinateMode mode) const;
+        virtual void addRepaintFull();
 
     private slots:
         void autoRaise();
@@ -507,7 +513,8 @@ class Client
         uint hidden : 1; ///< Forcibly hidden by calling hide()
         uint modal : 1; ///< NET::Modal
         uint noborder : 1;
-        uint app_noborder : 1; ///< The app requested no border using something (window type, motif hints)
+        uint app_noborder : 1; ///< App requested no border via window type, shape extension, etc.
+        uint motif_noborder : 1; ///< App requested no border via Motif WM hints
         uint urgency : 1; ///< XWMHints, UrgencyHint
         uint ignore_focus_stealing : 1; ///< Don't apply focus stealing prevention to this client
         uint demands_attention : 1;
