@@ -178,7 +178,12 @@ void KCommonDecoration::borders( int& left, int& right, int& top, int& bottom )
 
 void KCommonDecoration::updateLayout() const
 {
-    QRect r = widget()->rect();
+    const int paddingLeft   = layoutMetric(LM_OuterPaddingLeft);
+    const int paddingTop    = layoutMetric(LM_OuterPaddingTop);
+    const int paddingRight  = layoutMetric(LM_OuterPaddingRight);
+    const int paddingBottom = layoutMetric(LM_OuterPaddingBottom);
+
+    QRect r = widget()->rect().adjusted(paddingLeft, paddingTop, -paddingRight, -paddingBottom);
     int r_x, r_y, r_x2, r_y2;
     r.getCoords(&r_x, &r_y, &r_x2, &r_y2);
 
@@ -710,7 +715,8 @@ void KCommonDecoration::mouseDoubleClickEvent(QMouseEvent *e)
     if( e->button() != Qt::LeftButton )
         return;
 
-    int tb = layoutMetric(LM_TitleEdgeTop)+layoutMetric(LM_TitleHeight)+layoutMetric(LM_TitleEdgeBottom);
+    int tb = layoutMetric(LM_TitleEdgeTop) + layoutMetric(LM_TitleHeight) +
+        layoutMetric(LM_TitleEdgeBottom) + layoutMetric(LM_OuterPaddingTop);
     // when shaded, react on double clicks everywhere to make it easier to unshade. otherwise
     // react only on double clicks in the title bar region...
     if (isSetShade() || e->pos().y() <= tb )
@@ -719,7 +725,8 @@ void KCommonDecoration::mouseDoubleClickEvent(QMouseEvent *e)
 
 void KCommonDecoration::wheelEvent(QWheelEvent *e)
 {
-    int tb = layoutMetric(LM_TitleEdgeTop)+layoutMetric(LM_TitleHeight)+layoutMetric(LM_TitleEdgeBottom);
+    int tb = layoutMetric(LM_TitleEdgeTop) + layoutMetric(LM_TitleHeight) +
+        layoutMetric(LM_TitleEdgeBottom) + layoutMetric(LM_OuterPaddingTop);
     if (isSetShade() || e->pos().y() <= tb )
         titlebarMouseWheelOperation( e->delta());
 }
@@ -729,7 +736,12 @@ KCommonDecoration::Position KCommonDecoration::mousePosition(const QPoint &point
     const int corner = 18+3*layoutMetric(LM_BorderBottom, false)/2;
     Position pos = PositionCenter;
 
-    QRect r = widget()->rect();
+    const int paddingLeft   = layoutMetric(LM_OuterPaddingLeft);
+    const int paddingTop    = layoutMetric(LM_OuterPaddingTop);
+    const int paddingRight  = layoutMetric(LM_OuterPaddingRight);
+    const int paddingBottom = layoutMetric(LM_OuterPaddingBottom);
+
+    QRect r = widget()->rect().adjusted(paddingLeft, paddingTop, -paddingRight, -paddingBottom);
     int r_x, r_y, r_x2, r_y2;
     r.getCoords(&r_x, &r_y, &r_x2, &r_y2);
     int p_x = point.x();
@@ -876,8 +888,14 @@ bool KCommonDecoration::isToolWindow() const
 
 QRect KCommonDecoration::titleRect() const
 {
+    const int pl = layoutMetric(LM_OuterPaddingLeft);
+    const int pt = layoutMetric(LM_OuterPaddingTop);
+    const int pr = layoutMetric(LM_OuterPaddingRight);
+    const int pb = layoutMetric(LM_OuterPaddingBottom);
+
     int r_x, r_y, r_x2, r_y2;
-    widget()->rect().getCoords(&r_x, &r_y, &r_x2, &r_y2);
+    widget()->rect().adjusted(pl, pt, -pr, -pb).getCoords(&r_x, &r_y, &r_x2, &r_y2);
+
     const int titleEdgeLeft = layoutMetric(LM_TitleEdgeLeft);
     const int titleEdgeTop = layoutMetric(LM_TitleEdgeTop);
     const int titleEdgeRight = layoutMetric(LM_TitleEdgeRight);
@@ -1233,46 +1251,10 @@ KCommonDecorationUnstable::~KCommonDecorationUnstable()
     }
 
 // All copied from kdecoration.cpp
-QList<QRect> KCommonDecorationUnstable::shadowQuads( ShadowType type ) const
-    {
-    Q_UNUSED( type );
-    return QList<QRect>();
-    }
-double KCommonDecorationUnstable::shadowOpacity( ShadowType type ) const
-    {
-    if( isActive() && type == ShadowBorderedActive )
-        return 1.0;
-    else if( !isActive() && type == ShadowBorderedInactive )
-        return 1.0;
-    return 0.0;
-    }
-double KCommonDecorationUnstable::shadowBrightness( ShadowType type ) const
-    {
-    Q_UNUSED( type );
-    return 1.0;
-    }
-double KCommonDecorationUnstable::shadowSaturation( ShadowType type ) const
-    {
-    Q_UNUSED( type );
-    return 1.0;
-    }
-
-void KCommonDecorationUnstable::repaintShadow()
-    {
-    return static_cast<const KDecorationUnstable*>( decoration() )->repaintShadow();
-    }
 bool KCommonDecorationUnstable::compositingActive() const
     {
     return static_cast<const KDecorationUnstable*>( decoration() )->compositingActive();
     }
-bool KCommonDecorationUnstable::shadowsActive() const
-    {
-    return static_cast<const KDecorationUnstable*>( decoration() )->shadowsActive();
-    }
-double KCommonDecorationUnstable::opacity() const
-    {
-    return static_cast<const KDecorationUnstable*>( decoration() )->opacity();
-    }
 
 // kate: space-indent on; indent-width 4; mixedindent off; indent-mode cstyle;
 
