@@ -854,11 +854,11 @@ void Client::applyWindowRules()
     // see also Client::setActive()
     if( isActive())
         {
-        setOpacity( rules()->checkOpacityActive(opacity()*100)/100.0 );
+        setOpacity( rules()->checkOpacityActive( qRound( opacity() * 100.0 )) / 100.0 );
         workspace()->disableGlobalShortcutsForClient( rules()->checkDisableGlobalShortcuts( false ));
         }
     else
-        setOpacity( rules()->checkOpacityInactive(opacity()*100)/100.0 );
+        setOpacity( rules()->checkOpacityInactive( qRound( opacity() * 100.0 )) / 100.0 );
     }
 
 void Client::updateWindowRules()
