@@ -19,6 +19,7 @@
 
 #include <QGraphicsLayout>
 #include <QPainter>
+#include <QTimer>
 
 #include <KDebug>
 #include <KIcon>
@@ -30,40 +31,38 @@
 #include "calendar.h"
 
 
-CalendarTest::CalendarTest(QObject *parent, const QVariantList &args)
+CalendarApplet::CalendarApplet(QObject *parent, const QVariantList &args)
     : Plasma::PopupApplet(parent, args),
     m_calendarDialog(0),
     m_theme(0),
-    m_date(0),
-    m_updateTimerId(0)
+    m_date(0)
 {
     setAspectRatioMode(Plasma::IgnoreAspectRatio);
     setCacheMode(DeviceCoordinateCache);
 }
 
-void CalendarTest::init()
+void CalendarApplet::init()
 {
     setPopupIcon("view-pim-calendar");
     updateDate();
 }
 
-QGraphicsWidget *CalendarTest::graphicsWidget()
+QGraphicsWidget *CalendarApplet::graphicsWidget()
 {
     if (!m_calendarDialog) {
         m_calendarDialog = new Plasma::Calendar(this);
-        //m_calendarDialog->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
         m_calendarDialog->setPreferredSize(220, 250);
     }
 
     return m_calendarDialog;
 }
 
-CalendarTest::~CalendarTest()
+CalendarApplet::~CalendarApplet()
 {
 
 }
 
-void CalendarTest::constraintsEvent(Plasma::Constraints constraints)
+void CalendarApplet::constraintsEvent(Plasma::Constraints constraints)
 {
     if (!m_calendarDialog) {
         graphicsWidget();
@@ -75,7 +74,7 @@ void CalendarTest::constraintsEvent(Plasma::Constraints constraints)
     }
 }
 
-void CalendarTest::paintIcon()
+void CalendarApplet::paintIcon()
 {
     const int iconSize = qMin(size().width(), size().height());
 
@@ -106,28 +105,18 @@ void CalendarTest::paintIcon()
     setPopupIcon(icon);
 }
 
-void CalendarTest::configAccepted()
+void CalendarApplet::configAccepted()
 {
     update();
 }
 
-void CalendarTest::updateDate()
+void CalendarApplet::updateDate()
 {
     QDateTime d = QDateTime::currentDateTime();
     m_date = d.date().day();
     int updateIn = (24 * 60 * 60) - (d.toTime_t() + KSystemTimeZones::local().currentOffset()) % (24 * 60 * 60);
-    m_updateTimerId = startTimer(updateIn * 1000);
+    QTimer::singleShot(updateIn * 1000, this, SLOT(updateDate()));
     constraintsEvent(Plasma::FormFactorConstraint);
 }
 
-void CalendarTest::timerEvent(QTimerEvent *event)
-{
-    if (event->timerId() != m_updateTimerId) {
-        return;
-    }
-
-    killTimer(m_updateTimerId);
-    updateDate();
-}
-
 #include "calendar.moc"
