@@ -54,6 +54,7 @@ public:
           m_svg(new Plasma::Svg(this)),
           m_direction(direction)
     {
+        setAttribute(Qt::WA_TranslucentBackground);
         KWindowSystem::setOnAllDesktops(winId(), true);
         unsigned long state = NET::Sticky | NET::StaysOnTop | NET::KeepAbove;
         KWindowSystem::setState(winId(), state);
@@ -207,19 +208,18 @@ PanelView::PanelView(Plasma::Containment *panel, int id, QWidget *parent)
       m_triggerEntered(false)
 {
     Q_ASSERT(qobject_cast<Plasma::Corona*>(panel->scene()));
+    kDebug() << "Panel geometry is" << panel->geometry();
 
     m_strutsTimer = new QTimer(this);
     m_strutsTimer->setSingleShot(true);
     connect(m_strutsTimer, SIGNAL(timeout()), this, SLOT(updateStruts()));
 
-    if (panel) {
-        connect(panel, SIGNAL(destroyed(QObject*)), this, SLOT(panelDeleted()));
-        connect(panel, SIGNAL(toolBoxToggled()), this, SLOT(togglePanelController()));
-        kDebug() << "Panel geometry is" << panel->geometry();
-    }
-
+    connect(panel, SIGNAL(destroyed(QObject*)), this, SLOT(panelDeleted()));
+    connect(panel, SIGNAL(toolBoxToggled()), this, SLOT(togglePanelController()));
+    connect(panel, SIGNAL(appletAdded(Plasma::Applet *, const QPointF &)), this, SLOT(appletAdded(Plasma::Applet *)));
     connect(this, SIGNAL(sceneRectAboutToChange()), this, SLOT(pinchContainmentToCurrentScreen()));
 
+
     // Graphics view setup
     setFrameStyle(QFrame::NoFrame);
     //setAutoFillBackground(true);
@@ -240,22 +240,56 @@ PanelView::PanelView(Plasma::Containment *panel, int id, QWidget *parent)
 
     KConfigGroup viewConfig = config();
     KConfigGroup sizes = KConfigGroup(&viewConfig, "Sizes");
-    QRect screenRect = Kephal::ScreenUtils::screenGeometry(containment()->screen());
+    QRect screenRect = Kephal::ScreenUtils::screenGeometry(panel->screen());
+    m_lastHorizontal = isHorizontal();
     m_lastSeenSize = sizes.readEntry("lastsize", m_lastHorizontal ? screenRect.width() : screenRect.height());
     m_alignment = alignmentFilter((Qt::Alignment)viewConfig.readEntry("Alignment", (int)Qt::AlignLeft));
     m_offset = viewConfig.readEntry("Offset", 0);
-    m_lastHorizontal = isHorizontal();
 
     KWindowSystem::setType(winId(), NET::Dock);
 
+    // ensure we aren't overlapping other panels
+    const QRegion availGeom = PlasmaApp::self()->corona()->availableScreenRegion(panel->screen());
+    const int w = panel->size().width();
+    const int h = panel->size().height();
+    const int length = panel->formFactor() == Plasma::Horizontal ? w : h;
+
+    switch (location()) {
+        case Plasma::LeftEdge: {
+            QRect r = availGeom.intersected(QRect(0, m_offset, w, length)).boundingRect();
+            if (m_offset != r.top()) {
+                setOffset(r.top());
+            }
+        }
+        break;
+
+        case Plasma::RightEdge: {
+            QRect r = availGeom.intersected(QRect(screenRect.right() - w, m_offset, w, length)).boundingRect();
+            setOffset(r.top());
+        }
+        break;
+
+        case Plasma::TopEdge: {
+            QRect r = availGeom.intersected(QRect(m_offset, 0, length, h)).boundingRect();
+            setOffset(r.left());
+        }
+        break;
+
+        case Plasma::BottomEdge:
+        default: {
+            QRect r = availGeom.intersected(QRect(m_offset, screenRect.bottom() - h, length, h)).boundingRect();
+            setOffset(r.left());
+        }
+        break;
+    }
+
     // pinchContainment calls updatePanelGeometry for us
     pinchContainment(screenRect);
-    m_lastMin = containment()->minimumSize();
-    m_lastMax = containment()->maximumSize();
+    m_lastMin = panel->minimumSize();
+    m_lastMax = panel->maximumSize();
 
     // KWin setup
     KWindowSystem::setOnAllDesktops(winId(), true);
-
     QTimer::singleShot(0, this, SLOT(init()));
 }
 
@@ -356,7 +390,11 @@ void PanelView::setLocation(Plasma::Location location)
 
 Plasma::Location PanelView::location() const
 {
-    return containment()->location();
+    if (containment()) {
+        return containment()->location();
+    } else {
+        return Plasma::BottomEdge;
+    }
 }
 
 void PanelView::setVisibilityMode(PanelView::VisibilityMode mode)
@@ -377,9 +415,12 @@ void PanelView::setVisibilityMode(PanelView::VisibilityMode mode)
         state |= NET::StaysOnTop;
     }
 
-    if (mode == NormalPanel) {
+    if (mode == NormalPanel || mode == WindowsGoBelow) {
         // we need to kill the input window if it exists!
         destroyUnhideTrigger();
+        disconnect(containment(), SIGNAL(activate()), this, SLOT(unhide()));
+    } else {
+        connect(containment(), SIGNAL(activate()), this, SLOT(unhide()));
     }
 
     if (mode != AutoHide) {
@@ -393,6 +434,7 @@ void PanelView::setVisibilityMode(PanelView::VisibilityMode mode)
 
     m_visibilityMode = mode;
     config().writeEntry("panelVisibility", (int)mode);
+    configNeedsSaving();
 }
 
 PanelView::VisibilityMode PanelView::visibilityMode() const
@@ -408,6 +450,11 @@ Plasma::Corona *PanelView::corona() const
 void PanelView::updatePanelGeometry()
 {
     Plasma::Containment *c = containment();
+
+    if (!c) {
+        return;
+    }
+
     kDebug() << "New panel geometry is" << c->geometry();
 
     QSize size = c->size().toSize();
@@ -561,7 +608,7 @@ void PanelView::updatePanelGeometry()
             m_panelController->move(m_panelController->positionForPanelGeometry(geometry()));
         }
 
-        foreach (PanelAppletOverlay *o, m_moveOverlays) {
+        foreach (PanelAppletOverlay *o, m_appletOverlays) {
             o->syncOrientation();
         }
     }
@@ -575,6 +622,7 @@ bool PanelView::isHorizontal() const
 
 void PanelView::pinchContainmentToCurrentScreen()
 {
+    kDebug() << "pinching to current screen";
     QRect screenRect = Kephal::ScreenUtils::screenGeometry(containment()->screen());
     pinchContainment(screenRect);
 }
@@ -582,6 +630,7 @@ void PanelView::pinchContainmentToCurrentScreen()
 void PanelView::pinchContainment(const QRect &screenGeom)
 {
     kDebug() << "**************************** pinching" << screenGeom << m_lastSeenSize;
+    disconnect(this, SIGNAL(sceneRectAboutToChange()), this, SLOT(pinchContainmentToCurrentScreen()));
     bool horizontal = isHorizontal();
 
     int sw = screenGeom.width();
@@ -603,6 +652,7 @@ void PanelView::pinchContainment(const QRect &screenGeom)
         lastSize.writeEntry("offset", m_offset);
         lastSize.writeEntry("min", m_lastMin);
         lastSize.writeEntry("max", m_lastMax);
+        configNeedsSaving();
 
         QString last = (horizontal ? "Horizontal" : "Vertical") +
                        QString::number(horizontal ? sw : sh);
@@ -626,12 +676,21 @@ void PanelView::pinchContainment(const QRect &screenGeom)
                    (horizontal ? c->geometry().width() :
                                  c->geometry().height()) >= m_lastSeenSize) {
             // we are moving from a smaller space where we are 100% to a larger one
+            c->setMinimumSize(0, 0);
+            c->setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
+
             if (horizontal) {
                 c->setMaximumSize(sw, max.height());
                 c->resize(sw, c->geometry().height());
+                if (min.width() == max.width()) {
+                    c->setMinimumSize(sw, min.height());
+                }
             } else {
                 c->setMaximumSize(max.width(), sh);
                 c->resize(c->geometry().width(), sh);
+                if (min.height() == max.height()) {
+                    c->setMinimumSize(min.width(), sh);
+                }
             }
         }
     }
@@ -705,6 +764,7 @@ void PanelView::pinchContainment(const QRect &screenGeom)
         m_lastHorizontal = horizontal;
         m_lastSeenSize = (horizontal ? sw : sh);
         sizes.writeEntry("lastsize", m_lastSeenSize);
+        configNeedsSaving();
     }
 
     updatePanelGeometry();
@@ -714,6 +774,7 @@ void PanelView::pinchContainment(const QRect &screenGeom)
         m_panelController->setOffset(m_offset);
     }
 
+    connect(this, SIGNAL(sceneRectAboutToChange()), this, SLOT(pinchContainmentToCurrentScreen()));
     kDebug() << "Done pinching, containement's geom" << c->geometry() << "own geom" << geometry();
 }
 
@@ -728,6 +789,7 @@ void PanelView::setOffset(int newOffset)
     //TODO: do we ever need to worry about pinching here, or
     //      do we just assume that the offset is always < screenSize - containmentSize?
     updatePanelGeometry();
+    configNeedsSaving();
 }
 
 int PanelView::offset() const
@@ -740,6 +802,7 @@ void PanelView::setAlignment(Qt::Alignment align)
     m_alignment = alignmentFilter(align);
     KConfigGroup viewConfig = config();
     viewConfig.writeEntry("Alignment", (int)m_alignment);
+    configNeedsSaving();
 }
 
 Qt::Alignment PanelView::alignment() const
@@ -772,6 +835,9 @@ void PanelView::togglePanelController()
         connect(m_panelController, SIGNAL(panelVisibilityModeChanged(PanelView::VisibilityMode)), this, SLOT(setVisibilityMode(PanelView::VisibilityMode)));
 
         if (dynamic_cast<QGraphicsLinearLayout*>(containment()->layout())) {
+            setTabOrder(0, m_panelController);
+            QWidget *prior = m_panelController;
+
             // we only support mouse over drags for panels with linear layouts
             QColor overlayColor(Plasma::Theme::defaultTheme()->color(Plasma::Theme::BackgroundColor));
             QBrush overlayBrush(overlayColor);
@@ -779,18 +845,17 @@ void PanelView::togglePanelController()
             p.setBrush(QPalette::Window, overlayBrush);
             foreach (Plasma::Applet *applet, containment()->applets()) {
                 PanelAppletOverlay *moveOverlay = new PanelAppletOverlay(applet, this);
+                connect(moveOverlay, SIGNAL(removedWithApplet(PanelAppletOverlay*)),
+                        this, SLOT(overlayDestroyed(PanelAppletOverlay*)));
+                connect(moveOverlay, SIGNAL(moved(PanelAppletOverlay*)),
+                        this, SLOT(overlayMoved(PanelAppletOverlay*)));
                 moveOverlay->setPalette(p);
                 moveOverlay->show();
                 moveOverlay->raise();
-                m_moveOverlays << moveOverlay;
+                m_appletOverlays << moveOverlay;
                 //kDebug() << moveOverlay << moveOverlay->geometry();
-            }
-
-            setTabOrder(0, m_panelController);
-            QWidget *prior = m_panelController;
-            foreach (PanelAppletOverlay *w, m_moveOverlays) {
-                setTabOrder(prior, w);
-                prior = w;
+                setTabOrder(prior, moveOverlay);
+                prior = moveOverlay;
             }
         }
     }
@@ -811,15 +876,28 @@ void PanelView::edittingComplete()
     //kDebug();
     m_panelController = 0;
     m_editting = false;
-    qDeleteAll(m_moveOverlays);
-    m_moveOverlays.clear();
+    qDeleteAll(m_appletOverlays);
+    m_appletOverlays.clear();
     containment()->closeToolBox();
     updateStruts();
     m_firstPaint = true; // triggers autohide
 
-    // not overly efficient since we may not have changed any settings,
-    // but ensures that if we have, a config sync will occur
-    PlasmaApp::self()->corona()->requestConfigSync();
+    if (m_visibilityMode == LetWindowsCover) {
+         startAutoHide();
+    }
+}
+
+void PanelView::overlayDestroyed(PanelAppletOverlay *overlay)
+{
+    m_appletOverlays.remove(overlay);
+}
+
+void PanelView::overlayMoved(PanelAppletOverlay *overlay)
+{
+    Q_UNUSED(overlay)
+    foreach (PanelAppletOverlay *o, m_appletOverlays) {
+        o->syncIndex();
+    }
 }
 
 Qt::Alignment PanelView::alignmentFilter(Qt::Alignment align) const
@@ -834,7 +912,7 @@ Qt::Alignment PanelView::alignmentFilter(Qt::Alignment align) const
 
 void PanelView::updateStruts()
 {
-    if (!m_init) {
+    if (!m_init || !containment()) {
         return;
     }
 
@@ -844,6 +922,40 @@ void PanelView::updateStruts()
         QRect thisScreen = Kephal::ScreenUtils::screenGeometry(containment()->screen());
         QRect wholeScreen = Kephal::ScreenUtils::desktopGeometry();
 
+        //Extended struts against a screen edge near to another screen are really harmful, so windows maximized under the panel is a lesser pain
+        //TODO: force "windows can cover" in those cases?
+        foreach (Kephal::Screen *screen, Kephal::Screens::self()->screens()) {
+            QRect otherScreen = screen->geom();
+            switch (location())
+            {
+            case Plasma::TopEdge:
+                if (otherScreen.bottom() <= thisScreen.top()) {
+                    KWindowSystem::setExtendedStrut(winId(), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
+                    return;
+                }
+                break;
+            case Plasma::BottomEdge:
+                if (otherScreen.top() >= thisScreen.bottom()) {
+                    KWindowSystem::setExtendedStrut(winId(), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
+                    return;
+                }
+                break;
+            case Plasma::RightEdge:
+                if (otherScreen.left() >= thisScreen.right()) {
+                    KWindowSystem::setExtendedStrut(winId(), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
+                    return;
+                }
+                break;
+            case Plasma::LeftEdge:
+                if (otherScreen.right() <= thisScreen.left()) {
+                    KWindowSystem::setExtendedStrut(winId(), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
+                    return;
+                }
+                break;
+            default:
+                return;
+            }
+        }
         // extended struts are to the combined screen geoms, not the single screen
         int leftOffset = wholeScreen.x() - thisScreen.x();
         int rightOffset = wholeScreen.right() - thisScreen.right();
@@ -905,7 +1017,7 @@ void PanelView::updateStruts()
             m_panelController->move(m_panelController->positionForPanelGeometry(geometry()));
         }
 
-        foreach (PanelAppletOverlay *o, m_moveOverlays) {
+        foreach (PanelAppletOverlay *o, m_appletOverlays) {
             o->syncOrientation();
         }
     }
@@ -958,6 +1070,7 @@ QTimeLine *PanelView::timeLine()
 void PanelView::hideMousePoll()
 {
     QPoint mousePos = QCursor::pos();
+
     if (!geometry().contains(mousePos) && !hasPopup()) {
         startAutoHide();
     }
@@ -992,6 +1105,11 @@ bool PanelView::hintOrUnhide(const QPoint &point, bool dueToDnd)
         return false;
     }
 
+    KWindowInfo activeWindow = KWindowSystem::windowInfo(KWindowSystem::activeWindow(), NET::WMState);
+    if (activeWindow.state() & NET::FullScreen) {
+        return false;
+    }
+
     if (!shouldHintHide()) {
         //kDebug() << "should not hint hide";
         unhide(!dueToDnd);
@@ -999,8 +1117,6 @@ bool PanelView::hintOrUnhide(const QPoint &point, bool dueToDnd)
     }
 
     //kDebug() << point << m_triggerZone;
-//    if (point == QPoint()) {
-        //kDebug() << "enter, we should start glowing!";
     if (m_triggerZone.contains(point)) {
         //kDebug() << "unhide!" << point;
         unhide(!dueToDnd);
@@ -1016,6 +1132,7 @@ bool PanelView::hintOrUnhide(const QPoint &point, bool dueToDnd)
             m_mousePollTimer = new QTimer(this);
         }
 
+        disconnect(m_mousePollTimer, SIGNAL(timeout()), this, SLOT(unhideHintMousePoll()));
         connect(m_mousePollTimer, SIGNAL(timeout()), this, SLOT(unhideHintMousePoll()));
         m_mousePollTimer->start(200);
     }
@@ -1061,23 +1178,23 @@ void PanelView::unhide(bool destroyTrigger)
     unhintHide();
     if (destroyTrigger) {
         destroyUnhideTrigger();
-    } else {
-        if (!m_mousePollTimer) {
-            m_mousePollTimer = new QTimer(this);
-        }
-
-        disconnect(m_mousePollTimer, SIGNAL(timeout()), this, SLOT(hideMousePoll()));
-        connect(m_mousePollTimer, SIGNAL(timeout()), this, SLOT(hideMousePoll()));
-        m_mousePollTimer->start(200);
     }
 
+    if (!m_mousePollTimer) {
+        m_mousePollTimer = new QTimer(this);
+    }
+
+    disconnect(m_mousePollTimer, SIGNAL(timeout()), this, SLOT(hideMousePoll()));
+    connect(m_mousePollTimer, SIGNAL(timeout()), this, SLOT(hideMousePoll()));
+    m_mousePollTimer->start(200);
+
     // with composite, we can quite do some nice animations with transparent
     // backgrounds; without it we can't so we just show/hide
     QTimeLine * tl = timeLine();
     tl->setDirection(QTimeLine::Backward);
     tl->setDuration(100);
 
-    if (m_visibilityMode == AutoHide) {
+    if (m_visibilityMode == AutoHide || m_visibilityMode == LetWindowsCover) {
         // LetWindowsCover panels are always shown, so don't bother and prevent
         // some unsightly flickers
         show();
@@ -1101,6 +1218,11 @@ void PanelView::unhide(bool destroyTrigger)
     }
 }
 
+void PanelView::unhide()
+{
+    unhide(true);
+}
+
 void PanelView::resetTriggerEnteredSuppression()
 {
     m_triggerEntered = false;
@@ -1123,6 +1245,9 @@ void PanelView::startAutoHide()
         if (tl->state() == QTimeLine::NotRunning) {
             tl->start();
         }
+    } else if (m_visibilityMode == LetWindowsCover) {
+        KWindowSystem::lowerWindow(winId());
+        createUnhideTrigger();
     } else {
         animateHide(1.0);
     }
@@ -1130,14 +1255,11 @@ void PanelView::startAutoHide()
 
 void PanelView::leaveEvent(QEvent *event)
 {
-    if (m_visibilityMode == LetWindowsCover) {
-        if (m_triggerEntered) {
-            //kDebug() << "not creating!";
-            m_triggerEntered = false;
-        } else {
-            createUnhideTrigger();
-        }
-    } else if (m_visibilityMode == AutoHide && !m_editting) {
+    if (m_visibilityMode == LetWindowsCover && m_triggerEntered) {
+        //kDebug() << "not creating!";
+        m_triggerEntered = false;
+    } else if (containment() &&
+               (m_visibilityMode == AutoHide || m_visibilityMode == LetWindowsCover) && !m_editting) {
         // even if we dont have a popup, we'll start a timer, so
         // that the panel stays if the mouse only leaves for a
         // few ms
@@ -1191,6 +1313,45 @@ bool PanelView::event(QEvent *event)
     return Plasma::View::event(event);
 }
 
+void PanelView::appletAdded(Plasma::Applet *applet)
+{
+    if (m_panelController) {
+        QColor overlayColor(Plasma::Theme::defaultTheme()->color(Plasma::Theme::BackgroundColor));
+        QBrush overlayBrush(overlayColor);
+        QPalette p(palette());
+        p.setBrush(QPalette::Window, overlayBrush);
+
+        PanelAppletOverlay *moveOverlay = new PanelAppletOverlay(applet, this);
+        connect(moveOverlay, SIGNAL(removedWithApplet(PanelAppletOverlay*)),
+                this, SLOT(overlayDestroyed(PanelAppletOverlay*)));
+        moveOverlay->setPalette(p);
+        moveOverlay->show();
+        moveOverlay->raise();
+        m_appletOverlays << moveOverlay;
+
+        QWidget *prior = m_panelController;
+        Plasma::Applet *priorApplet = 0;
+        foreach (Plasma::Applet *otherApplet, containment()->applets()) {
+            if (applet == otherApplet) {
+                break;
+            }
+
+            priorApplet = otherApplet;
+        }
+
+        if (priorApplet) {
+            foreach (PanelAppletOverlay *overlay, m_appletOverlays) {
+                if (overlay->applet() == priorApplet) {
+                    prior = overlay;
+                    break;
+                }
+            }
+        }
+
+        setTabOrder(prior, moveOverlay);
+    }
+}
+
 void PanelView::animateHide(qreal progress)
 {
     if (m_visibilityMode == AutoHide && shouldHintHide()) {
@@ -1373,8 +1534,13 @@ void PanelView::panelDeleted()
         // the panel was removed at runtime; clean up our configuration object as well
         KConfigGroup c = config();
         c.deleteGroup();
+        configNeedsSaving();
     }
 
+    delete m_mousePollTimer;
+    m_mousePollTimer = 0;
+    m_strutsTimer->stop();
+
     deleteLater();
 }
 
@@ -1430,31 +1596,6 @@ void PanelView::positionSpacer(const QPoint pos)
     }
 }
 
-void PanelView::dragEnterEvent(QDragEnterEvent *event)
-{
-    Plasma::Containment *c = containment();
-    if (c && c->immutability() == Plasma::Mutable &&
-        (event->mimeData()->hasFormat(static_cast<Plasma::Corona*>(scene())->appletMimeType()) ||
-         KUrl::List::canDecode(event->mimeData()))) {
-        containment()->showDropZone(event->pos());
-    }
-
-    //the containment will do the last decision whether accept it or not
-    Plasma::View::dragEnterEvent(event);
-}
-
-void PanelView::dragMoveEvent(QDragMoveEvent *event)
-{
-    Plasma::Containment *c = containment();
-    if (c && c->immutability() == Plasma::Mutable &&
-        (event->mimeData()->hasFormat(static_cast<Plasma::Corona*>(scene())->appletMimeType()) ||
-         KUrl::List::canDecode(event->mimeData()))) {
-        containment()->showDropZone(event->pos());
-    }
-
-    Plasma::View::dragMoveEvent(event);
-}
-
 void PanelView::dragLeaveEvent(QDragLeaveEvent *event)
 {
     if (containment()) {
